@@ -145,7 +145,7 @@ class TestBzrDir(TestCaseWithBzrDir):
 
             rev_trees_a = sorted(left_repo.revision_trees(all_revs), key=sort_key)
             rev_trees_b = sorted(right_repo.revision_trees(all_revs), key=sort_key)
-            for tree_a, tree_b in zip(rev_trees_a, rev_trees_b):
+            for tree_a, tree_b in zip(rev_trees_a, rev_trees_b, strict=False):
                 self.assertEqual([], list(tree_a.iter_changes(tree_b)))
             # texts
             text_index = left_repo._generate_text_key_index()
@@ -703,7 +703,7 @@ class TestBzrDir(TestCaseWithBzrDir):
         """
         if not self.bzrdir_format.is_initializable():
             raise TestNotApplicable("control dir format is not initializable")
-        repo, control, require_stacking, repo_policy = (
+        repo, control, _require_stacking, _repo_policy = (
             self.bzrdir_format.initialize_on_transport_ex(t, **kwargs)
         )
         if repo is not None:
