@@ -17,15 +17,12 @@
 
 """Directory service for gitorious."""
 
-from __future__ import absolute_import
-
 from .. import transport
 
-transport.register_urlparse_netloc_protocol('github')
+transport.register_urlparse_netloc_protocol("github")
 
 
-class GitHubDirectory(object):
-
+class GitHubDirectory:
     def look_up(self, name, url, purpose=None):
-        """See DirectoryService.look_up"""
+        """See DirectoryService.look_up."""
         return "git+ssh://git@github.com/" + name
