@@ -23,7 +23,7 @@ from collections.abc import Iterable, Iterator
 from typing import AbstractSet
 
 from dulwich.object_store import BaseObjectStore
-from dulwich.objects import ZERO_SHA, Blob, Commit, ObjectID, ShaFile, Tree, sha_to_hex
+from dulwich.objects import ZERO_SHA, Blob, Commit, ObjectID, Tree, sha_to_hex
 from dulwich.pack import Pack, PackData, UnpackedObject, pack_objects_to_data
 
 from .. import errors, lru_cache, osutils, trace, ui
@@ -381,6 +381,14 @@ class BazaarObjectStore(BaseObjectStore):
     """A Git-style object store backed onto a Bazaar repository."""
 
     def __init__(self, repository, mapping=None):
+        """Initialize BazaarObjectStore.
+
+        Args:
+            repository: The Bazaar repository to wrap.
+            mapping: Optional mapping for Git/Bazaar conversion.
+        """
+        from dulwich.object_format import DEFAULT_OBJECT_FORMAT
+
         self.repository = repository
         self._map_updated = False
         self._locked = None
@@ -395,6 +403,7 @@ class BazaarObjectStore(BaseObjectStore):
         self.commit_write_group = self._cache.idmap.commit_write_group
         self.tree_cache = LRUTreeCache(self.repository)
         self.unpeel_map = UnpeelMap.from_repository(self.repository)
+        self.object_format = DEFAULT_OBJECT_FORMAT
 
     def _missing_revisions(self, revisions):
         return self._cache.idmap.missing_revisions(revisions)
@@ -513,7 +522,9 @@ class BazaarObjectStore(BaseObjectStore):
             rev, root_tree.id, lossy=lossy, verifiers=verifiers
         )
         try:
-            foreign_revid, mapping = mapping_registry.parse_revision_id(rev.revision_id)
+            foreign_revid, _mapping = mapping_registry.parse_revision_id(
+                rev.revision_id
+            )
         except errors.InvalidRevisionId:
             pass
         else:
@@ -856,7 +867,9 @@ class BazaarObjectStore(BaseObjectStore):
                     for path, obj in self._revision_to_objects(rev, tree, lossy=lossy):
                         if obj.id not in seen:
                             # Convert path to bytes for PackHint compatibility
-                            path_bytes = encode_git_path(path) if path is not None else None
+                            path_bytes = (
+                                encode_git_path(path) if path is not None else None
+                            )
                             yield (obj.id, (obj.type_num, path_bytes))
                             seen.add(obj.id)
 
