@@ -22,7 +22,6 @@ from ... import commitfromnews
 
 
 class TestRegisters(TestCaseWithTransport):
-
     def test_registered_at_import(self):
         self.assertTrue(commitfromnews._registered)
 
@@ -30,5 +29,5 @@ class TestRegisters(TestCaseWithTransport):
         commitfromnews._registered = False
         # Registers only within the plugin
         commitfromnews.register()
-        self.assertLength(1, msgeditor.hooks['commit_message_template'])
+        self.assertLength(1, msgeditor.hooks["commit_message_template"])
         self.assertTrue(commitfromnews._registered)
