@@ -303,7 +303,7 @@ class TestImportToPackTag(TestCaseForGenericProcessor):
         return command_list
 
     def test_tag(self):
-        handler, branch = self.get_handler()
+        handler, _branch = self.get_handler()
         path = b"a"
         raise tests.KnownFailure("non-mark committish not yet supported- bug #410249")
         handler.process(self.file_command_iter(path))
@@ -311,7 +311,7 @@ class TestImportToPackTag(TestCaseForGenericProcessor):
 
 class TestImportZeroMarker(TestCaseForGenericProcessor):
     def test_tag(self):
-        handler, branch = self.get_handler()
+        handler, _branch = self.get_handler()
 
         def command_list():
             committer = [b"", b"elmer@a.com", time.time(), time.timezone]
@@ -364,7 +364,7 @@ class TestImportToPackModify(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a"
         handler.process(self.file_command_iter(path))
-        revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(path,)])
+        _revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(path,)])
         revtree1, revtree2 = self.assertChanges(branch, 2, expected_modified=[(path,)])
         self.assertContent(branch, revtree1, path, b"aaa")
         self.assertContent(branch, revtree2, path, b"bbb")
@@ -375,7 +375,7 @@ class TestImportToPackModify(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/a"
         handler.process(self.file_command_iter(path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path,)]
         )
         revtree1, revtree2 = self.assertChanges(branch, 2, expected_modified=[(path,)])
@@ -396,7 +396,7 @@ class TestImportToPackModify(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/a"
         handler.process(self.file_command_iter(path, kind="symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path,)]
         )
         revtree1, revtree2 = self.assertChanges(branch, 2, expected_modified=[(path,)])
@@ -407,7 +407,7 @@ class TestImportToPackModify(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/a"
         handler.process(self.file_command_iter(path, kind="file", to_kind="symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -420,7 +420,7 @@ class TestImportToPackModify(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/a"
         handler.process(self.file_command_iter(path, kind="symlink", to_kind="file"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -437,7 +437,7 @@ class TestImportToPackModify(TestCaseForGenericProcessor):
                 path, executable=False, to_executable=True, to_content=b"aaa"
             )
         )
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path,)]
         )
         revtree1, revtree2 = self.assertChanges(branch, 2, expected_modified=[(path,)])
@@ -452,7 +452,7 @@ class TestImportToPackModify(TestCaseForGenericProcessor):
                 path, executable=True, to_executable=False, to_content=b"aaa"
             )
         )
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path,)]
         )
         revtree1, revtree2 = self.assertChanges(branch, 2, expected_modified=[(path,)])
@@ -504,7 +504,7 @@ class TestImportToPackModifyTwice(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a"
         handler.process(self.file_command_iter(path))
-        revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(path,)])
+        _revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(path,)])
         self.assertContent(branch, revtree1, path, b"aaa")
         self.assertRevisionRoot(revtree1, path)
 
@@ -545,7 +545,7 @@ class TestImportToPackModifyTricky(TestCaseForGenericProcessor):
         path1 = b"a/b"
         path2 = b"a/b/c"
         handler.process(self.file_command_iter(path1, path2))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path1,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -562,7 +562,7 @@ class TestImportToPackModifyTricky(TestCaseForGenericProcessor):
         path1 = b"a/b/c"
         path2 = b"a/b"
         handler.process(self.file_command_iter(path1, path2))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (b"a/b",), (path1,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -581,7 +581,7 @@ class TestImportToPackModifyTricky(TestCaseForGenericProcessor):
         path1 = b"a/b"
         path2 = b"a/b/c"
         handler.process(self.file_command_iter(path1, path2, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path1,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -598,7 +598,7 @@ class TestImportToPackModifyTricky(TestCaseForGenericProcessor):
         path1 = b"a/b/c"
         path2 = b"a/b"
         handler.process(self.file_command_iter(path1, path2, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (b"a/b",), (path1,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -643,8 +643,8 @@ class TestImportToPackDelete(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a"
         handler.process(self.file_command_iter(path))
-        revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(path,)])
-        revtree1, revtree2 = self.assertChanges(branch, 2, expected_removed=[(path,)])
+        _revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(path,)])
+        revtree1, _revtree2 = self.assertChanges(branch, 2, expected_removed=[(path,)])
         self.assertContent(branch, revtree1, path, b"aaa")
         self.assertRevisionRoot(revtree1, path)
 
@@ -652,10 +652,10 @@ class TestImportToPackDelete(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/a"
         handler.process(self.file_command_iter(path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path,)]
         )
-        revtree1, revtree2 = self.assertChanges(
+        revtree1, _revtree2 = self.assertChanges(
             branch, 2, expected_removed=[(b"a",), (path,)]
         )
         self.assertContent(branch, revtree1, path, b"aaa")
@@ -664,7 +664,7 @@ class TestImportToPackDelete(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a"
         handler.process(self.file_command_iter(path, kind="symlink"))
-        revtree1, revtree2 = self.assertChanges(branch, 2, expected_removed=[(path,)])
+        revtree1, _revtree2 = self.assertChanges(branch, 2, expected_removed=[(path,)])
         self.assertSymlinkTarget(branch, revtree1, path, "aaa")
         self.assertRevisionRoot(revtree1, path)
 
@@ -672,10 +672,10 @@ class TestImportToPackDelete(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/a"
         handler.process(self.file_command_iter(path, kind="symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path,)]
         )
-        revtree1, revtree2 = self.assertChanges(
+        revtree1, _revtree2 = self.assertChanges(
             branch, 2, expected_removed=[(b"a",), (path,)]
         )
         self.assertSymlinkTarget(branch, revtree1, path, "aaa")
@@ -684,10 +684,10 @@ class TestImportToPackDelete(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/b/c/d"
         handler.process(self.file_command_iter(path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (b"a/b",), (b"a/b/c",), (path,)]
         )
-        revtree1, revtree2 = self.assertChanges(
+        revtree1, _revtree2 = self.assertChanges(
             branch, 2, expected_removed=[(b"a",), (b"a/b",), (b"a/b/c",), (path,)]
         )
         self.assertContent(branch, revtree1, path, b"aaa")
@@ -718,7 +718,7 @@ class TestImportToPackDeleteNew(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a"
         handler.process(self.file_command_iter(path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, _revtree1 = self.assertChanges(
             branch,
             1,
         )
@@ -727,7 +727,7 @@ class TestImportToPackDeleteNew(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/a"
         handler.process(self.file_command_iter(path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, _revtree1 = self.assertChanges(
             branch,
             1,
         )
@@ -736,7 +736,7 @@ class TestImportToPackDeleteNew(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a"
         handler.process(self.file_command_iter(path, kind="symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, _revtree1 = self.assertChanges(
             branch,
             1,
         )
@@ -745,7 +745,7 @@ class TestImportToPackDeleteNew(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/a"
         handler.process(self.file_command_iter(path, kind="symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, _revtree1 = self.assertChanges(
             branch,
             1,
         )
@@ -754,7 +754,7 @@ class TestImportToPackDeleteNew(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/b/c/d"
         handler.process(self.file_command_iter(path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, _revtree1 = self.assertChanges(
             branch,
             1,
         )
@@ -793,7 +793,7 @@ class TestImportToPackDeleteMultiLevel(TestCaseForGenericProcessor):
         paths = [b"a/b/c", b"a/b/d/e"]
         paths_to_delete = [b"a/b/c", b"a/b/d/e"]
         handler.process(self.file_command_iter(paths, paths_to_delete))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch,
             1,
             expected_added=[
@@ -804,7 +804,7 @@ class TestImportToPackDeleteMultiLevel(TestCaseForGenericProcessor):
                 (b"a/b/d/e",),
             ],
         )
-        revtree1, revtree2 = self.assertChanges(
+        _revtree1, _revtree2 = self.assertChanges(
             branch,
             2,
             expected_removed=[
@@ -821,7 +821,7 @@ class TestImportToPackDeleteMultiLevel(TestCaseForGenericProcessor):
         paths = [b"a/b/c", b"a/b/d/e"]
         paths_to_delete = [b"a/b/d/e"]
         handler.process(self.file_command_iter(paths, paths_to_delete))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch,
             1,
             expected_added=[
@@ -832,7 +832,7 @@ class TestImportToPackDeleteMultiLevel(TestCaseForGenericProcessor):
                 (b"a/b/d/e",),
             ],
         )
-        revtree1, revtree2 = self.assertChanges(
+        _revtree1, _revtree2 = self.assertChanges(
             branch,
             2,
             expected_removed=[
@@ -846,7 +846,7 @@ class TestImportToPackDeleteMultiLevel(TestCaseForGenericProcessor):
         paths = [b"a/b/c", b"a/b/d/e", b"a/f/g", b"a/h", b"a/b/d/i/j"]
         paths_to_delete = [b"a/b/c", b"a/b/d/e", b"a/f/g", b"a/b/d/i/j"]
         handler.process(self.file_command_iter(paths, paths_to_delete))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch,
             1,
             expected_added=[
@@ -862,7 +862,7 @@ class TestImportToPackDeleteMultiLevel(TestCaseForGenericProcessor):
                 (b"a/b/d/i/j",),
             ],
         )
-        revtree1, revtree2 = self.assertChanges(
+        _revtree1, _revtree2 = self.assertChanges(
             branch,
             2,
             expected_removed=[
@@ -927,7 +927,7 @@ class TestImportToPackDeleteThenAdd(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a"
         handler.process(self.file_command_iter(path))
-        revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(path,)])
+        _revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(path,)])
         revtree1, revtree2 = self.assertChanges(
             branch, 2, expected_removed=[(path,)], expected_added=[(path,)]
         )
@@ -940,7 +940,7 @@ class TestImportToPackDeleteThenAdd(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/a"
         handler.process(self.file_command_iter(path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -965,7 +965,7 @@ class TestImportToPackDeleteThenAdd(TestCaseForGenericProcessor):
         handler, branch = self.get_handler()
         path = b"a/a"
         handler.process(self.file_command_iter(path, kind="symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -1007,7 +1007,7 @@ class TestImportToPackDeleteDirectory(TestCaseForGenericProcessor):
         paths = [b"a/b/c", b"a/b/d", b"a/b/e/f", b"a/g"]
         dir = b"a/b"
         handler.process(self.file_command_iter(paths, dir))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch,
             1,
             expected_added=[
@@ -1020,7 +1020,7 @@ class TestImportToPackDeleteDirectory(TestCaseForGenericProcessor):
                 (b"a/g",),
             ],
         )
-        revtree1, revtree2 = self.assertChanges(
+        _revtree1, _revtree2 = self.assertChanges(
             branch,
             2,
             expected_removed=[
@@ -1071,7 +1071,7 @@ class TestImportToPackDeleteDirectoryThenAddFile(TestCaseForGenericProcessor):
         dir = b"a/b"
         new_path = b"a/b/z"
         handler.process(self.file_command_iter(paths, dir, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch,
             1,
             expected_added=[
@@ -1081,7 +1081,7 @@ class TestImportToPackDeleteDirectoryThenAddFile(TestCaseForGenericProcessor):
                 (b"a/b/d",),
             ],
         )
-        revtree1, revtree2 = self.assertChanges(
+        _revtree1, revtree2 = self.assertChanges(
             branch,
             2,
             expected_removed=[(b"a/b",), (b"a/b/c",), (b"a/b/d",)],
@@ -1095,7 +1095,7 @@ class TestImportToPackDeleteDirectoryThenAddFile(TestCaseForGenericProcessor):
         dir = b"a/b"
         new_path = b"a/b/z"
         handler.process(self.file_command_iter(paths, dir, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch,
             1,
             expected_added=[
@@ -1105,7 +1105,7 @@ class TestImportToPackDeleteDirectoryThenAddFile(TestCaseForGenericProcessor):
                 (b"a/b/d",),
             ],
         )
-        revtree1, revtree2 = self.assertChanges(
+        _revtree1, revtree2 = self.assertChanges(
             branch,
             2,
             expected_removed=[(b"a/b",), (b"a/b/c",), (b"a/b/d",)],
@@ -1229,7 +1229,9 @@ class TestImportToPackRenameNew(TestCaseForGenericProcessor):
         old_path = b"a"
         new_path = b"b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(new_path,)])
+        _revtree0, revtree1 = self.assertChanges(
+            branch, 1, expected_added=[(new_path,)]
+        )
         self.assertRevisionRoot(revtree1, new_path)
 
     def test_rename_new_symlink_in_root(self):
@@ -1237,7 +1239,9 @@ class TestImportToPackRenameNew(TestCaseForGenericProcessor):
         old_path = b"a"
         new_path = b"b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(new_path,)])
+        _revtree0, revtree1 = self.assertChanges(
+            branch, 1, expected_added=[(new_path,)]
+        )
         self.assertRevisionRoot(revtree1, new_path)
 
     def test_rename_new_file_in_subdir(self):
@@ -1245,7 +1249,7 @@ class TestImportToPackRenameNew(TestCaseForGenericProcessor):
         old_path = b"a/a"
         new_path = b"a/b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, _revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (new_path,)]
         )
 
@@ -1254,7 +1258,7 @@ class TestImportToPackRenameNew(TestCaseForGenericProcessor):
         old_path = b"a/a"
         new_path = b"a/b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, _revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (new_path,)]
         )
 
@@ -1296,7 +1300,7 @@ class TestImportToPackRenameToDeleted(TestCaseForGenericProcessor):
         old_path = b"a"
         new_path = b"b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(old_path,), (new_path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -1316,7 +1320,7 @@ class TestImportToPackRenameToDeleted(TestCaseForGenericProcessor):
         old_path = b"a"
         new_path = b"b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(old_path,), (new_path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -1336,7 +1340,7 @@ class TestImportToPackRenameToDeleted(TestCaseForGenericProcessor):
         old_path = b"d/a"
         new_path = b"d/b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d",), (old_path,), (new_path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -1354,7 +1358,7 @@ class TestImportToPackRenameToDeleted(TestCaseForGenericProcessor):
         old_path = b"d/a"
         new_path = b"d/b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d",), (old_path,), (new_path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -1372,7 +1376,7 @@ class TestImportToPackRenameToDeleted(TestCaseForGenericProcessor):
         old_path = b"d1/a"
         new_path = b"d2/b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d1",), (old_path,), (b"d2",), (new_path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -1390,7 +1394,7 @@ class TestImportToPackRenameToDeleted(TestCaseForGenericProcessor):
         old_path = b"d1/a"
         new_path = b"d2/b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d1",), (old_path,), (b"d2",), (new_path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -1440,7 +1444,9 @@ class TestImportToPackRenameModified(TestCaseForGenericProcessor):
         old_path = b"a"
         new_path = b"b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(old_path,)])
+        _revtree0, revtree1 = self.assertChanges(
+            branch, 1, expected_added=[(old_path,)]
+        )
         # Note: the delta doesn't show the modification?
         # The actual new content is validated in the assertions following.
         revtree1, revtree2 = self.assertChanges(
@@ -1456,7 +1462,9 @@ class TestImportToPackRenameModified(TestCaseForGenericProcessor):
         old_path = b"a"
         new_path = b"b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(old_path,)])
+        _revtree0, revtree1 = self.assertChanges(
+            branch, 1, expected_added=[(old_path,)]
+        )
         # Note: the delta doesn't show the modification?
         # The actual new content is validated in the assertions following.
         revtree1, revtree2 = self.assertChanges(
@@ -1472,7 +1480,7 @@ class TestImportToPackRenameModified(TestCaseForGenericProcessor):
         old_path = b"d/a"
         new_path = b"d/b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d",), (old_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1488,7 +1496,7 @@ class TestImportToPackRenameModified(TestCaseForGenericProcessor):
         old_path = b"d/a"
         new_path = b"d/b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d",), (old_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1504,7 +1512,7 @@ class TestImportToPackRenameModified(TestCaseForGenericProcessor):
         old_path = b"d1/a"
         new_path = b"d2/b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d1",), (old_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1524,7 +1532,7 @@ class TestImportToPackRenameModified(TestCaseForGenericProcessor):
         old_path = b"d1/a"
         new_path = b"d2/b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d1",), (old_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1576,7 +1584,9 @@ class TestImportToPackRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"a"
         new_path = b"b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(old_path,)])
+        _revtree0, revtree1 = self.assertChanges(
+            branch, 1, expected_added=[(old_path,)]
+        )
         # Note: the delta doesn't show the modification?
         # The actual new content is validated in the assertions following.
         revtree1, revtree2 = self.assertChanges(
@@ -1592,7 +1602,7 @@ class TestImportToPackRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"d/a"
         new_path = b"d/b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d",), (old_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1608,7 +1618,7 @@ class TestImportToPackRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"d1/a"
         new_path = b"d2/b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d1",), (old_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1628,7 +1638,9 @@ class TestImportToPackRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"a"
         new_path = b"b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(branch, 1, expected_added=[(old_path,)])
+        _revtree0, revtree1 = self.assertChanges(
+            branch, 1, expected_added=[(old_path,)]
+        )
         # Note: the delta doesn't show the modification?
         # The actual new content is validated in the assertions following.
         revtree1, revtree2 = self.assertChanges(
@@ -1644,7 +1656,7 @@ class TestImportToPackRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"d/a"
         new_path = b"d/b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d",), (old_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1660,7 +1672,7 @@ class TestImportToPackRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"d1/a"
         new_path = b"d2/b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d1",), (old_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1716,7 +1728,7 @@ class TestImportToPackDeleteRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"a"
         new_path = b"b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(old_path,), (new_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1739,7 +1751,7 @@ class TestImportToPackDeleteRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"d/a"
         new_path = b"d/b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d",), (old_path,), (new_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1759,7 +1771,7 @@ class TestImportToPackDeleteRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"d1/a"
         new_path = b"d2/b"
         handler.process(self.get_command_iter(old_path, new_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d1",), (b"d2",), (old_path,), (new_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1779,7 +1791,7 @@ class TestImportToPackDeleteRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"a"
         new_path = b"b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(old_path,), (new_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1802,7 +1814,7 @@ class TestImportToPackDeleteRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"d/a"
         new_path = b"d/b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d",), (old_path,), (new_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1822,7 +1834,7 @@ class TestImportToPackDeleteRenameThenModify(TestCaseForGenericProcessor):
         old_path = b"d1/a"
         new_path = b"d2/b"
         handler.process(self.get_command_iter(old_path, new_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d1",), (b"d2",), (old_path,), (new_path,)]
         )
         # Note: the delta doesn't show the modification?
@@ -1876,7 +1888,7 @@ class TestImportToPackRenameTricky(TestCaseForGenericProcessor):
         path1 = b"a/b"
         new_path2 = b"a/b/c"
         handler.process(self.file_command_iter(path1, old_path2, new_path2))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path1,), (old_path2,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -1894,7 +1906,7 @@ class TestImportToPackRenameTricky(TestCaseForGenericProcessor):
         path1 = b"a/b/c"
         new_path2 = b"a/b"
         handler.process(self.file_command_iter(path1, old_path2, new_path2))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (b"a/b",), (path1,), (old_path2,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -1912,7 +1924,7 @@ class TestImportToPackRenameTricky(TestCaseForGenericProcessor):
         path1 = b"a/b"
         new_path2 = b"a/b/c"
         handler.process(self.file_command_iter(path1, old_path2, new_path2, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (path1,), (old_path2,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -1930,7 +1942,7 @@ class TestImportToPackRenameTricky(TestCaseForGenericProcessor):
         path1 = b"a/b/c"
         new_path2 = b"a/b"
         handler.process(self.file_command_iter(path1, old_path2, new_path2, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (b"a/b",), (path1,), (old_path2,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -2072,7 +2084,7 @@ class TestImportToPackCopyNew(TestCaseForGenericProcessor):
         src_path = b"a"
         dest_path = b"b"
         handler.process(self.file_command_iter(src_path, dest_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(src_path,), (dest_path,)]
         )
         self.assertContent(branch, revtree1, src_path, b"aaa")
@@ -2085,7 +2097,7 @@ class TestImportToPackCopyNew(TestCaseForGenericProcessor):
         src_path = b"a/a"
         dest_path = b"a/b"
         handler.process(self.file_command_iter(src_path, dest_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (src_path,), (dest_path,)]
         )
         self.assertContent(branch, revtree1, src_path, b"aaa")
@@ -2096,7 +2108,7 @@ class TestImportToPackCopyNew(TestCaseForGenericProcessor):
         src_path = b"a/a"
         dest_path = b"b/a"
         handler.process(self.file_command_iter(src_path, dest_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (src_path,), (b"b",), (dest_path,)]
         )
         self.assertContent(branch, revtree1, src_path, b"aaa")
@@ -2107,7 +2119,7 @@ class TestImportToPackCopyNew(TestCaseForGenericProcessor):
         src_path = b"a"
         dest_path = b"b"
         handler.process(self.file_command_iter(src_path, dest_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(src_path,), (dest_path,)]
         )
         self.assertSymlinkTarget(branch, revtree1, src_path, "aaa")
@@ -2120,7 +2132,7 @@ class TestImportToPackCopyNew(TestCaseForGenericProcessor):
         src_path = b"a/a"
         dest_path = b"a/b"
         handler.process(self.file_command_iter(src_path, dest_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (src_path,), (dest_path,)]
         )
         self.assertSymlinkTarget(branch, revtree1, src_path, "aaa")
@@ -2131,7 +2143,7 @@ class TestImportToPackCopyNew(TestCaseForGenericProcessor):
         src_path = b"a/a"
         dest_path = b"b/a"
         handler.process(self.file_command_iter(src_path, dest_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"a",), (src_path,), (b"b",), (dest_path,)]
         )
         self.assertSymlinkTarget(branch, revtree1, src_path, "aaa")
@@ -2173,7 +2185,7 @@ class TestImportToPackCopyToDeleted(TestCaseForGenericProcessor):
         src_path = b"a"
         dest_path = b"b"
         handler.process(self.file_command_iter(src_path, dest_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(src_path,), (dest_path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -2191,7 +2203,7 @@ class TestImportToPackCopyToDeleted(TestCaseForGenericProcessor):
         src_path = b"a"
         dest_path = b"b"
         handler.process(self.file_command_iter(src_path, dest_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(src_path,), (dest_path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -2209,7 +2221,7 @@ class TestImportToPackCopyToDeleted(TestCaseForGenericProcessor):
         src_path = b"d/a"
         dest_path = b"d/b"
         handler.process(self.file_command_iter(src_path, dest_path))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d",), (src_path,), (dest_path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -2225,7 +2237,7 @@ class TestImportToPackCopyToDeleted(TestCaseForGenericProcessor):
         src_path = b"d/a"
         dest_path = b"d/b"
         handler.process(self.file_command_iter(src_path, dest_path, "symlink"))
-        revtree0, revtree1 = self.assertChanges(
+        _revtree0, revtree1 = self.assertChanges(
             branch, 1, expected_added=[(b"d",), (src_path,), (dest_path,)]
         )
         revtree1, revtree2 = self.assertChanges(
@@ -2368,11 +2380,11 @@ class TestImportToPackFileKinds(TestCaseForGenericProcessor):
         return command_list
 
     def test_import_plainfile(self):
-        handler, branch = self.get_handler()
+        handler, _branch = self.get_handler()
         handler.process(self.get_command_iter(b"foo", "file", b"aaa"))
 
     def test_import_symlink(self):
-        handler, branch = self.get_handler()
+        handler, _branch = self.get_handler()
         handler.process(self.get_command_iter(b"foo", "symlink", b"bar"))
 
 
