@@ -44,13 +44,13 @@ class cmd_fetch_all_records(Command):
         try:
             source = ControlDir.open(source_repo).open_repository()
         except (errors.NotBranchError, urlutils.InvalidURL):
-            print("Not a branch or invalid URL: %s" % source_repo, file=self.outf)
+            print("Not a branch or invalid URL: {}".format(source_repo), file=self.outf)
             return
 
         try:
             target = ControlDir.open(directory).open_repository()
         except (errors.NotBranchError, urlutils.InvalidURL):
-            print("Not a branch or invalid URL: %s" % directory, file=self.outf)
+            print("Not a branch or invalid URL: {}".format(directory), file=self.outf)
             return
 
         self.add_cleanup(source.lock_read().unlock)
