@@ -100,7 +100,7 @@ class TestGrep(GrepTestBase):
         self.assertEqual(len(out.splitlines()), 0)
 
         # unknown file is not grepped unless explicitely specified
-        out, err = self.run_bzr(["grep", "line1$"])
+        out, _err = self.run_bzr(["grep", "line1$"])
         self.assertNotContainsRe(out, "file0.txt", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 0)
 
@@ -120,7 +120,7 @@ class TestGrep(GrepTestBase):
         self.assertEqual(len(out.splitlines()), 9)
 
         # finds all the lines
-        out, err = self.run_bzr(["grep", "-r", "1", "line[0-9]", "file0.txt"])
+        out, _err = self.run_bzr(["grep", "-r", "1", "line[0-9]", "file0.txt"])
         self.assertContainsRe(out, "file0.txt~1:line1", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 10)
 
@@ -144,7 +144,7 @@ class TestGrep(GrepTestBase):
         self.assertNotContainsRe(out, "file0.txt", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 0)
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "[A-Z]{3}", "file0.txt"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "[A-Z]{3}", "file0.txt"])
         self.assertNotContainsRe(out, "file0.txt", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 0)
 
@@ -184,7 +184,7 @@ class TestGrep(GrepTestBase):
         # two lines each (line1, line10) from file0.aa and file0.bb
         self.assertEqual(len(out.splitlines()), 4)
 
-        out, err = self.run_bzr(
+        out, _err = self.run_bzr(
             ["grep", "-r", "last:1", "-I", "*.aa", "-I", "*.bb", "line1$"]
         )
         self.assertContainsRe(out, "file0.aa~.:line1", flags=TestGrep._reflags)
@@ -211,7 +211,7 @@ class TestGrep(GrepTestBase):
         # two lines each (line1, line10) from file0.aa and file0.bb
         self.assertEqual(len(out.splitlines()), 4)
 
-        out, err = self.run_bzr(
+        out, _err = self.run_bzr(
             ["grep", "--include", "*.aa", "--include", "*.bb", "line1$"]
         )
         self.assertContainsRe(out, "file0.aa:line1", flags=TestGrep._reflags)
@@ -245,7 +245,7 @@ class TestGrep(GrepTestBase):
         # one line each (line1) from file0.aa and file0.bb
         self.assertEqual(len(out.splitlines()), 2)
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "-X", "*.cc", "line1"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "-X", "*.cc", "line1"])
         self.assertContainsRe(out, "file0.aa~.:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "file0.bb~.:line1", flags=TestGrep._reflags)
         self.assertNotContainsRe(out, "file0.cc", flags=TestGrep._reflags)
@@ -268,7 +268,7 @@ class TestGrep(GrepTestBase):
         # two lines each (line1, line10) from file0.aa and file0.bb
         self.assertEqual(len(out.splitlines()), 4)
 
-        out, err = self.run_bzr(["grep", "--exclude", "*.cc", "lin.1$"])
+        out, _err = self.run_bzr(["grep", "--exclude", "*.cc", "lin.1$"])
         self.assertContainsRe(out, "file0.aa:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "file0.bb:line1", flags=TestGrep._reflags)
         self.assertNotContainsRe(out, "file0.cc", flags=TestGrep._reflags)
@@ -293,7 +293,7 @@ class TestGrep(GrepTestBase):
         self.assertContainsRe(out, "file2.txt~.:line2", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 6)
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "line"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "line"])
         self.assertContainsRe(out, "file0.txt~.:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "file0.txt~.:line2", flags=TestGrep._reflags)
         self.assertContainsRe(out, "file1.txt~.:line1", flags=TestGrep._reflags)
@@ -341,7 +341,7 @@ class TestGrep(GrepTestBase):
         self.assertContainsRe(out, "file2.txt:HELLO", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 3)
 
-        out, err = self.run_bzr(
+        out, _err = self.run_bzr(
             ["grep", "HE..O", "-r", "last:1", "file0.txt", "file1.txt", "file2.txt"]
         )
 
@@ -371,7 +371,7 @@ class TestGrep(GrepTestBase):
         self.assertEqual(nout, nref)
         self.assertEqual(len(out.splitlines()), 1)
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "--null", "line"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "--null", "line"])
         nout = ud.normalize("NFC", out)
         self.assertEqual(nout, nref)
         self.assertEqual(len(out.splitlines()), 1)
@@ -391,7 +391,7 @@ class TestGrep(GrepTestBase):
         self.assertEqual(out, "file0.txt:line1\0file0.txt:line2\0file0.txt:line3\0")
         self.assertEqual(len(out.splitlines()), 1)
 
-        out, err = self.run_bzr(["grep", "-Z", "line"])
+        out, _err = self.run_bzr(["grep", "-Z", "line"])
         self.assertEqual(out, "file0.txt:line1\0file0.txt:line2\0file0.txt:line3\0")
         self.assertEqual(len(out.splitlines()), 1)
 
@@ -408,7 +408,7 @@ class TestGrep(GrepTestBase):
         self.assertNotContainsRe(out, "file0.txt~.:line1", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 0)
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "--no-recursive", "line1$"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "--no-recursive", "line1$"])
         self.assertNotContainsRe(out, "file0.txt~.:line1", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 0)
 
@@ -425,7 +425,7 @@ class TestGrep(GrepTestBase):
         self.assertNotContainsRe(out, "file0.txt:line1", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 0)
 
-        out, err = self.run_bzr(["grep", "--no-recursive", "lin.1"])
+        out, _err = self.run_bzr(["grep", "--no-recursive", "lin.1"])
         self.assertNotContainsRe(out, "file0.txt:line1", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 0)
 
@@ -442,7 +442,7 @@ class TestGrep(GrepTestBase):
         # find line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
 
-        out, err = self.run_bzr(["grep", "-r", "-1", "line1"])
+        out, _err = self.run_bzr(["grep", "-r", "-1", "line1"])
         self.assertContainsRe(out, "^dir0/file0.txt~.:line1", flags=TestGrep._reflags)
         # find line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
@@ -460,7 +460,7 @@ class TestGrep(GrepTestBase):
         # find line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
 
-        out, err = self.run_bzr(["grep", "lin.1"])
+        out, _err = self.run_bzr(["grep", "lin.1"])
         self.assertContainsRe(out, "^dir0/file0.txt:line1", flags=TestGrep._reflags)
         # find line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
@@ -479,7 +479,7 @@ class TestGrep(GrepTestBase):
         # finds line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", ".i.e1"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", ".i.e1"])
         self.assertContainsRe(out, "^file0.txt~.:line1", flags=TestGrep._reflags)
         # finds line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
@@ -521,7 +521,7 @@ class TestGrep(GrepTestBase):
         # finds line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
 
-        out, err = self.run_bzr(
+        out, _err = self.run_bzr(
             ["grep", "-r", "last:3..last:1", "--include", "*.aa", "lin.1"]
         )
         self.assertContainsRe(out, "^file1.aa~3:line1$", flags=TestGrep._reflags)
@@ -550,7 +550,7 @@ class TestGrep(GrepTestBase):
         # finds line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
 
-        out, err = self.run_bzr(
+        out, _err = self.run_bzr(
             ["grep", "-r", "last:1", "--exclude", "*.txt", "l[a-z]ne1"]
         )
         self.assertContainsRe(out, "^file1.aa~.:line1", flags=TestGrep._reflags)
@@ -572,7 +572,7 @@ class TestGrep(GrepTestBase):
         # finds line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
 
-        out, err = self.run_bzr(["grep", "l[aeiou]ne1"])
+        out, _err = self.run_bzr(["grep", "l[aeiou]ne1"])
         self.assertContainsRe(out, "^file0.txt:line1", flags=TestGrep._reflags)
         # finds line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
@@ -592,7 +592,7 @@ class TestGrep(GrepTestBase):
         # finds line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
 
-        out, err = self.run_bzr(["grep", "--include", "*.aa", "l[ixn]ne1"])
+        out, _err = self.run_bzr(["grep", "--include", "*.aa", "l[ixn]ne1"])
         self.assertContainsRe(out, "^file1.aa:line1", flags=TestGrep._reflags)
         self.assertNotContainsRe(out, "file0.txt", flags=TestGrep._reflags)
         # finds line1 and line10
@@ -615,7 +615,7 @@ class TestGrep(GrepTestBase):
         # finds line1 and line10
         self.assertEqual(len(out.splitlines()), 2)
 
-        out, err = self.run_bzr(["grep", "--exclude", "*.txt", "line1"])
+        out, _err = self.run_bzr(["grep", "--exclude", "*.txt", "line1"])
         self.assertContainsRe(out, "^file1.aa:line1$", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^file1.aa:line10$", flags=TestGrep._reflags)
         self.assertNotContainsRe(out, "file0.txt", flags=TestGrep._reflags)
@@ -648,7 +648,7 @@ class TestGrep(GrepTestBase):
         # finds line1 and line10
         self.assertEqual(len(out.splitlines()), 4)
 
-        out, err = self.run_bzr(
+        out, _err = self.run_bzr(
             ["grep", "-r", "last:1", "--include", "*.aa", "--include", "*.bb", "line1"]
         )
         self.assertContainsRe(out, "^dir0/file0.aa~.:line1$", flags=TestGrep._reflags)
@@ -685,7 +685,7 @@ class TestGrep(GrepTestBase):
         # finds line1 and line10
         self.assertEqual(len(out.splitlines()), 4)
 
-        out, err = self.run_bzr(
+        out, _err = self.run_bzr(
             ["grep", "--include", "*.aa", "--include", "*.bb", "line1"]
         )
         self.assertContainsRe(out, "^dir0/file0.aa:line1$", flags=TestGrep._reflags)
@@ -716,7 +716,7 @@ class TestGrep(GrepTestBase):
         self.assertContainsRe(out, "^dir1/file1.bb~.:line1", flags=TestGrep._reflags)
         self.assertNotContainsRe(out, "file1.cc", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "--exclude", "*.cc", "line1"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "--exclude", "*.cc", "line1"])
         self.assertContainsRe(out, "^dir0/file0.aa~.:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir1/file1.bb~.:line1", flags=TestGrep._reflags)
         self.assertNotContainsRe(out, "file1.cc", flags=TestGrep._reflags)
@@ -741,7 +741,7 @@ class TestGrep(GrepTestBase):
         self.assertContainsRe(out, "^dir1/file1.bb:line1", flags=TestGrep._reflags)
         self.assertNotContainsRe(out, "file1.cc", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "--exclude", "*.cc", "line1"])
+        out, _err = self.run_bzr(["grep", "--exclude", "*.cc", "line1"])
         self.assertContainsRe(out, "^dir0/file0.aa:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir1/file1.bb:line1", flags=TestGrep._reflags)
         self.assertNotContainsRe(out, "file1.cc", flags=TestGrep._reflags)
@@ -762,7 +762,7 @@ class TestGrep(GrepTestBase):
         self.assertContainsRe(out, "^dir0/file0.txt:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir1/file1.txt:line1", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "line1", "dir0", "dir1"])
+        out, _err = self.run_bzr(["grep", "line1", "dir0", "dir1"])
         self.assertContainsRe(out, "^dir0/file0.txt:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir1/file1.txt:line1", flags=TestGrep._reflags)
 
@@ -782,7 +782,7 @@ class TestGrep(GrepTestBase):
         self.assertContainsRe(out, "^dir0/file0.txt~.:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir1/file1.txt~.:line1", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "line1", "dir0", "dir1"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "line1", "dir0", "dir1"])
         self.assertContainsRe(out, "^dir0/file0.txt~.:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir1/file1.txt~.:line1", flags=TestGrep._reflags)
 
@@ -802,7 +802,7 @@ class TestGrep(GrepTestBase):
         self.assertContainsRe(out, "^dir0/file0.txt:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir1/file1.txt:line1", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "line1", "dir0", "dir1"])
+        out, _err = self.run_bzr(["grep", "line1", "dir0", "dir1"])
         self.assertContainsRe(out, "^dir0/file0.txt:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir1/file1.txt:line1", flags=TestGrep._reflags)
 
@@ -836,7 +836,7 @@ class TestGrep(GrepTestBase):
             out, "^dir0/dir00/file0.txt~.:line1", flags=TestGrep._reflags
         )
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "line1"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "line1"])
         self.assertContainsRe(
             out, "^dir0/dir00/file0.txt~.:line1", flags=TestGrep._reflags
         )
@@ -871,7 +871,7 @@ class TestGrep(GrepTestBase):
             out, "^dir0/dir00/file0.txt:line1", flags=TestGrep._reflags
         )
 
-        out, err = self.run_bzr(["grep", "line1"])
+        out, _err = self.run_bzr(["grep", "line1"])
         self.assertContainsRe(
             out, "^dir0/dir00/file0.txt:line1", flags=TestGrep._reflags
         )
@@ -905,7 +905,7 @@ class TestGrep(GrepTestBase):
             out, "^dir0/dir1/file0.txt~.:line1", flags=TestGrep._reflags
         )
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "--no-recursive", "line1"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "--no-recursive", "line1"])
         self.assertNotContainsRe(out, "file0.txt", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 0)
 
@@ -938,7 +938,7 @@ class TestGrep(GrepTestBase):
             out, "^dir0/dir1/file0.txt:line1", flags=TestGrep._reflags
         )
 
-        out, err = self.run_bzr(["grep", "--no-recursive", "line1"])
+        out, _err = self.run_bzr(["grep", "--no-recursive", "line1"])
         self.assertNotContainsRe(out, "file0.txt", flags=TestGrep._reflags)
 
     def test_versioned_ignore_case_no_match(self):
@@ -951,7 +951,7 @@ class TestGrep(GrepTestBase):
         out, err = self.run_bzr(["grep", "-r", "last:1", "LinE1", "file0.txt"])
         self.assertNotContainsRe(out, "file0.txt~.:line1", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "Li.E1", "file0.txt"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "Li.E1", "file0.txt"])
         self.assertNotContainsRe(out, "file0.txt~.:line1", flags=TestGrep._reflags)
 
     def test_wtree_ignore_case_no_match(self):
@@ -964,7 +964,7 @@ class TestGrep(GrepTestBase):
         out, err = self.run_bzr(["grep", "LinE1", "file0.txt"])
         self.assertNotContainsRe(out, "file0.txt:line1", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", ".inE1", "file0.txt"])
+        out, _err = self.run_bzr(["grep", ".inE1", "file0.txt"])
         self.assertNotContainsRe(out, "file0.txt:line1", flags=TestGrep._reflags)
 
     def test_versioned_ignore_case_match(self):
@@ -980,7 +980,7 @@ class TestGrep(GrepTestBase):
         out, err = self.run_bzr(["grep", "-r", "last:1", "-i", "LinE1", "file0.txt"])
         self.assertContainsRe(out, "file0.txt~.:line1", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(
+        out, _err = self.run_bzr(
             ["grep", "-r", "last:1", "--ignore-case", "LinE1", "file0.txt"]
         )
         self.assertContainsRe(out, "^file0.txt~.:line1", flags=TestGrep._reflags)
@@ -998,7 +998,7 @@ class TestGrep(GrepTestBase):
         out, err = self.run_bzr(["grep", "--ignore-case", "LinE1", "file0.txt"])
         self.assertContainsRe(out, "^file0.txt:line1", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "--ignore-case", "Li.E1", "file0.txt"])
+        out, _err = self.run_bzr(["grep", "--ignore-case", "Li.E1", "file0.txt"])
         self.assertContainsRe(out, "^file0.txt:line1", flags=TestGrep._reflags)
 
     def test_versioned_from_root_fail(self):
@@ -1013,7 +1013,7 @@ class TestGrep(GrepTestBase):
         out, err = self.run_bzr(["grep", "-r", "last:1", "li.e1"])
         self.assertNotContainsRe(out, "file0.txt", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "line1"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "line1"])
         self.assertNotContainsRe(out, "file0.txt", flags=TestGrep._reflags)
 
     def test_wtree_from_root_fail(self):
@@ -1028,7 +1028,7 @@ class TestGrep(GrepTestBase):
         out, err = self.run_bzr(["grep", "line1"])
         self.assertNotContainsRe(out, "file0.txt", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "li.e1"])
+        out, _err = self.run_bzr(["grep", "li.e1"])
         self.assertNotContainsRe(out, "file0.txt", flags=TestGrep._reflags)
 
     def test_versioned_from_root_pass(self):
@@ -1043,7 +1043,7 @@ class TestGrep(GrepTestBase):
         out, err = self.run_bzr(["grep", "-r", "last:1", "--from-root", "l.ne1"])
         self.assertContainsRe(out, "file0.txt~.:line1", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "-r", "last:1", "--from-root", "line1"])
+        out, _err = self.run_bzr(["grep", "-r", "last:1", "--from-root", "line1"])
         self.assertContainsRe(out, "file0.txt~.:line1", flags=TestGrep._reflags)
 
     def test_wtree_from_root_pass(self):
@@ -1058,7 +1058,7 @@ class TestGrep(GrepTestBase):
         out, err = self.run_bzr(["grep", "--from-root", "lin.1"])
         self.assertContainsRe(out, "file0.txt:line1", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "--from-root", "line1"])
+        out, _err = self.run_bzr(["grep", "--from-root", "line1"])
         self.assertContainsRe(out, "file0.txt:line1", flags=TestGrep._reflags)
 
     def test_versioned_with_line_number(self):
@@ -1081,7 +1081,7 @@ class TestGrep(GrepTestBase):
         out, err = self.run_bzr(["grep", "-r", "last:1", "-n", "line1", "file0.txt"])
         self.assertContainsRe(out, "file0.txt~.:1:line1", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "-n", "line[0-9]", "file0.txt"])
+        out, _err = self.run_bzr(["grep", "-n", "line[0-9]", "file0.txt"])
         self.assertContainsRe(out, "file0.txt:3:line3", flags=TestGrep._reflags)
 
     def test_wtree_with_line_number(self):
@@ -1100,7 +1100,7 @@ class TestGrep(GrepTestBase):
         out, err = self.run_bzr(["grep", "-n", "[hjkl]ine1", "file0.txt"])
         self.assertContainsRe(out, "file0.txt:1:line1", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "-n", "line[0-9]", "file0.txt"])
+        out, _err = self.run_bzr(["grep", "-n", "line[0-9]", "file0.txt"])
         self.assertContainsRe(out, "file0.txt:3:line3", flags=TestGrep._reflags)
 
     def test_revno_basic_history_grep_file(self):
@@ -1135,7 +1135,7 @@ class TestGrep(GrepTestBase):
         self.assertContainsRe(out, "file0.txt~3:v3.*", flags=TestGrep._reflags)
 
         # rev 3 should not have text 'v3' with line number
-        out, err = self.run_bzr(["grep", "-r", "3", "-n", "[tuv]3", fname])
+        out, _err = self.run_bzr(["grep", "-r", "3", "-n", "[tuv]3", fname])
         self.assertContainsRe(out, "file0.txt~3:2:v3.*", flags=TestGrep._reflags)
 
     def test_revno_basic_history_grep_full(self):
@@ -1171,7 +1171,7 @@ class TestGrep(GrepTestBase):
         self.assertContainsRe(out, "file0.txt~3:v3", flags=TestGrep._reflags)
 
         # rev 3 should not have text 'v3' with line number
-        out, err = self.run_bzr(["grep", "-r", "3", "-n", "[tuv]3"])
+        out, _err = self.run_bzr(["grep", "-r", "3", "-n", "[tuv]3"])
         self.assertContainsRe(out, "file0.txt~3:1:v3", flags=TestGrep._reflags)
 
     def test_revno_versioned_file_in_dir(self):
@@ -1198,7 +1198,7 @@ class TestGrep(GrepTestBase):
         self.assertNotContainsRe(out, "^dir0/file0.txt", flags=TestGrep._reflags)
 
         # v4 should be present in revno 4
-        out, err = self.run_bzr(["grep", "-r", "last:2", "[tuv]4"])
+        out, _err = self.run_bzr(["grep", "-r", "last:2", "[tuv]4"])
         self.assertContainsRe(out, "^dir0/file0.txt~4:v4", flags=TestGrep._reflags)
 
     def test_revno_range_basic_history_grep(self):
@@ -1267,7 +1267,7 @@ class TestGrep(GrepTestBase):
         self.assertNotContainsRe(out, "file0.txt~6:v3", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 3)
 
-        out, err = self.run_bzr(["grep", "-r", "5..1", "[tuv]3"])
+        out, _err = self.run_bzr(["grep", "-r", "5..1", "[tuv]3"])
         self.assertContainsRe(out, "file0.txt~3:v3", flags=TestGrep._reflags)
         self.assertContainsRe(out, "file0.txt~4:v3", flags=TestGrep._reflags)
         self.assertContainsRe(out, "file0.txt~5:v3", flags=TestGrep._reflags)
@@ -1293,7 +1293,7 @@ class TestGrep(GrepTestBase):
         self.assertNotContainsRe(out, "^dir0/file0.txt~6:v3", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 3)
 
-        out, err = self.run_bzr(["grep", "-r", "2..5", "[tuv]3"])
+        out, _err = self.run_bzr(["grep", "-r", "2..5", "[tuv]3"])
         self.assertContainsRe(out, "^dir0/file0.txt~3:v3", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir0/file0.txt~4:v3", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir0/file0.txt~5:v3", flags=TestGrep._reflags)
@@ -1318,7 +1318,7 @@ class TestGrep(GrepTestBase):
         self.assertContainsRe(out, "^dir0/file0.txt~5:v3", flags=TestGrep._reflags)
         self.assertNotContainsRe(out, "^dir0/file0.txt~6:v3", flags=TestGrep._reflags)
 
-        out, err = self.run_bzr(["grep", "-r", "2..5", "[tuv]3", "dir0"])
+        out, _err = self.run_bzr(["grep", "-r", "2..5", "[tuv]3", "dir0"])
         self.assertContainsRe(out, "^dir0/file0.txt~3:v3", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir0/file0.txt~4:v3", flags=TestGrep._reflags)
         self.assertContainsRe(out, "^dir0/file0.txt~5:v3", flags=TestGrep._reflags)
@@ -1399,7 +1399,7 @@ class TestGrep(GrepTestBase):
         self.assertContainsRe(out, "^file1.txt~1.1.1:line10$", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 8)
 
-        out, err = self.run_bzr(["grep", "-r", "-1..", "-n", "--levels=0", ".ine1"])
+        out, _err = self.run_bzr(["grep", "-r", "-1..", "-n", "--levels=0", ".ine1"])
         self.assertContainsRe(out, "file0.txt~2:1:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "file1.txt~2:1:line1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "file0.txt~1.1.1:1:line1", flags=TestGrep._reflags)
@@ -1426,7 +1426,7 @@ class TestGrep(GrepTestBase):
         out, err = self.run_bzr(["merge", osutils.pathjoin("..", wd1)])
         out, err = self.run_bzr(["ci", "-m", "merged"])
 
-        out, err = self.run_bzr(["grep", "-r", "1.1.1..1.1.4", "text"])
+        out, _err = self.run_bzr(["grep", "-r", "1.1.1..1.1.4", "text"])
         self.assertContainsRe(out, "file1.txt~1.1.2:text 0", flags=TestGrep._reflags)
         self.assertContainsRe(out, "file1.txt~1.1.3:text 1", flags=TestGrep._reflags)
         self.assertContainsRe(out, "file1.txt~1.1.3:text 1", flags=TestGrep._reflags)
@@ -1504,7 +1504,7 @@ class TestGrep(GrepTestBase):
         self.assertNotContainsRe(out, "file0", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 0)
 
-        out, err = self.run_bzr(["grep", "-r", "..revno:3", "v3"])
+        out, _err = self.run_bzr(["grep", "-r", "..revno:3", "v3"])
         self.assertContainsRe(out, "^dir0/file0.txt", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 1)
 
@@ -1582,7 +1582,7 @@ class TestGrep(GrepTestBase):
         self.assertEqual(len(out.splitlines()), 1)
 
         # regex
-        out, err = self.run_bzr(["grep", "--no-recursive", "-l", ".ELLO"])
+        out, _err = self.run_bzr(["grep", "--no-recursive", "-l", ".ELLO"])
 
         self.assertContainsRe(out, "^file0.txt$", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 1)
@@ -1681,7 +1681,7 @@ class TestGrep(GrepTestBase):
         self.assertEqual(len(out.splitlines()), 1)
 
         # regex
-        out, err = self.run_bzr(["grep", "--no-recursive", "-r", "-1", "-l", ".ELLO"])
+        out, _err = self.run_bzr(["grep", "--no-recursive", "-r", "-1", "-l", ".ELLO"])
 
         self.assertContainsRe(out, "^file0.txt~7$", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 1)
@@ -1762,7 +1762,7 @@ class TestGrep(GrepTestBase):
         self.assertEqual(len(out.splitlines()), 1)
 
         # regex
-        out, err = self.run_bzr(["grep", "--no-recursive", "-L", ".ELLO"])
+        out, _err = self.run_bzr(["grep", "--no-recursive", "-L", ".ELLO"])
 
         self.assertContainsRe(out, "^file1.txt$", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 1)
@@ -1871,7 +1871,7 @@ class TestGrep(GrepTestBase):
         self.assertEqual(len(out.splitlines()), 1)
 
         # regex
-        out, err = self.run_bzr(["grep", "--no-recursive", "-r", "-1", "-L", ".ELLO"])
+        out, _err = self.run_bzr(["grep", "--no-recursive", "-r", "-1", "-L", ".ELLO"])
 
         self.assertContainsRe(out, "^file1.txt~7$", flags=TestGrep._reflags)
         self.assertEqual(len(out.splitlines()), 1)
@@ -2074,7 +2074,7 @@ class TestColorGrep(GrepTestBase):
         self.assertEqual(out, nres)
         self.assertEqual(len(out.splitlines()), 1)
 
-        out, err = self.run_bzr(
+        out, _err = self.run_bzr(
             ["grep", "-n", "-i", "--color", "always", "-r", "1", "F.O"]
         )
         self.assertEqual(out, nres)
@@ -2133,7 +2133,7 @@ class TestColorGrep(GrepTestBase):
         self.assertEqual(out, nres)
         self.assertEqual(len(out.splitlines()), 1)
 
-        out, err = self.run_bzr(["grep", "-n", "-i", "--color", "always", "F.O"])
+        out, _err = self.run_bzr(["grep", "-n", "-i", "--color", "always", "F.O"])
         self.assertEqual(out, nres)
         self.assertEqual(len(out.splitlines()), 1)
 
