@@ -20,33 +20,39 @@ from .. import lru_cache, tests
 
 
 def walk_lru(lru):
-    """Test helper to walk the LRU list and assert its consistency"""
+    """Test helper to walk the LRU list and assert its consistency."""
     node = lru._most_recently_used
     if node is not None:
         if node.prev is not None:
-            raise AssertionError('the _most_recently_used entry is not'
-                                 ' supposed to have a previous entry'
-                                 ' %s' % (node,))
+            raise AssertionError(
+                "the _most_recently_used entry is not"
+                " supposed to have a previous entry"
+                " {}".format(node)
+            )
     while node is not None:
         if node.next_key is lru_cache._null_key:
             if node is not lru._least_recently_used:
-                raise AssertionError('only the last node should have'
-                                     ' no next value: %s' % (node,))
+                raise AssertionError(
+                    "only the last node should have no next value: {}".format(node)
+                )
             node_next = None
         else:
             node_next = lru._cache[node.next_key]
             if node_next.prev is not node:
-                raise AssertionError('inconsistency found, node.next.prev'
-                                     ' != node: %s' % (node,))
+                raise AssertionError(
+                    "inconsistency found, node.next.prev != node: {}".format(node)
+                )
         if node.prev is None:
             if node is not lru._most_recently_used:
-                raise AssertionError('only the _most_recently_used should'
-                                     ' not have a previous node: %s'
-                                     % (node,))
+                raise AssertionError(
+                    "only the _most_recently_used should"
+                    " not have a previous node: {}".format(node)
+                )
         else:
             if node.prev.next_key != node.key:
-                raise AssertionError('inconsistency found, node.prev.next'
-                                     ' != node: %s' % (node,))
+                raise AssertionError(
+                    "inconsistency found, node.prev.next != node: {}".format(node)
+                )
         yield node
         node = node_next
 
@@ -67,13 +73,13 @@ class TestLRUCache(tests.TestCase):
     def test_missing(self):
         cache = lru_cache.LRUCache(max_cache=10)
 
-        self.assertFalse('foo' in cache)
-        self.assertRaises(KeyError, cache.__getitem__, 'foo')
+        self.assertFalse("foo" in cache)
+        self.assertRaises(KeyError, cache.__getitem__, "foo")
 
-        cache['foo'] = 'bar'
-        self.assertEqual('bar', cache['foo'])
-        self.assertTrue('foo' in cache)
-        self.assertFalse('bar' in cache)
+        cache["foo"] = "bar"
+        self.assertEqual("bar", cache["foo"])
+        self.assertTrue("foo" in cache)
+        self.assertFalse("bar" in cache)
 
     def test_map_None(self):
         # Make sure that we can properly map None as a key.
@@ -94,35 +100,34 @@ class TestLRUCache(tests.TestCase):
 
     def test_add__null_key(self):
         cache = lru_cache.LRUCache(max_cache=10)
-        self.assertRaises(ValueError,
-                          cache.__setitem__, lru_cache._null_key, 1)
+        self.assertRaises(ValueError, cache.__setitem__, lru_cache._null_key, 1)
 
     def test_overflow(self):
         """Adding extra entries will pop out old ones."""
         cache = lru_cache.LRUCache(max_cache=1, after_cleanup_count=1)
 
-        cache['foo'] = 'bar'
+        cache["foo"] = "bar"
         # With a max cache of 1, adding 'baz' should pop out 'foo'
-        cache['baz'] = 'biz'
+        cache["baz"] = "biz"
 
-        self.assertFalse('foo' in cache)
-        self.assertTrue('baz' in cache)
+        self.assertFalse("foo" in cache)
+        self.assertTrue("baz" in cache)
 
-        self.assertEqual('biz', cache['baz'])
+        self.assertEqual("biz", cache["baz"])
 
     def test_by_usage(self):
         """Accessing entries bumps them up in priority."""
         cache = lru_cache.LRUCache(max_cache=2)
 
-        cache['baz'] = 'biz'
-        cache['foo'] = 'bar'
+        cache["baz"] = "biz"
+        cache["foo"] = "bar"
 
-        self.assertEqual('biz', cache['baz'])
+        self.assertEqual("biz", cache["baz"])
 
         # This must kick out 'foo' because it was the last accessed
-        cache['nub'] = 'in'
+        cache["nub"] = "in"
 
-        self.assertFalse('foo' in cache)
+        self.assertFalse("foo" in cache)
 
     def test_len(self):
         cache = lru_cache.LRUCache(max_cache=10, after_cleanup_count=10)
@@ -151,8 +156,9 @@ class TestLRUCache(tests.TestCase):
 
         # We hit the max
         self.assertEqual(10, len(cache))
-        self.assertEqual([11, 10, 9, 1, 8, 7, 6, 5, 4, 3],
-                         [n.key for n in walk_lru(cache)])
+        self.assertEqual(
+            [11, 10, 9, 1, 8, 7, 6, 5, 4, 3], [n.key for n in walk_lru(cache)]
+        )
 
     def test_cleanup_shrinks_to_after_clean_count(self):
         cache = lru_cache.LRUCache(max_cache=5, after_cleanup_count=3)
@@ -278,7 +284,6 @@ class TestLRUCache(tests.TestCase):
 
 
 class TestLRUSizeCache(tests.TestCase):
-
     def test_basic_init(self):
         cache = lru_cache.LRUSizeCache()
         self.assertEqual(2048, cache._max_cache)
@@ -287,21 +292,20 @@ class TestLRUSizeCache(tests.TestCase):
 
     def test_add__null_key(self):
         cache = lru_cache.LRUSizeCache()
-        self.assertRaises(ValueError,
-                          cache.__setitem__, lru_cache._null_key, 1)
+        self.assertRaises(ValueError, cache.__setitem__, lru_cache._null_key, 1)
 
     def test_add_tracks_size(self):
         cache = lru_cache.LRUSizeCache()
         self.assertEqual(0, cache._value_size)
-        cache['my key'] = 'my value text'
+        cache["my key"] = "my value text"
         self.assertEqual(13, cache._value_size)
 
     def test_remove_tracks_size(self):
         cache = lru_cache.LRUSizeCache()
         self.assertEqual(0, cache._value_size)
-        cache['my key'] = 'my value text'
+        cache["my key"] = "my value text"
         self.assertEqual(13, cache._value_size)
-        node = cache._cache['my key']
+        node = cache._cache["my key"]
         cache._remove_node(node)
         self.assertEqual(0, cache._value_size)
 
@@ -310,71 +314,72 @@ class TestLRUSizeCache(tests.TestCase):
         cache = lru_cache.LRUSizeCache(max_size=10, after_cleanup_size=5)
         self.assertEqual(0, cache._value_size)
         self.assertEqual({}, cache.as_dict())
-        cache['test'] = 'key'
+        cache["test"] = "key"
         self.assertEqual(3, cache._value_size)
-        self.assertEqual({'test': 'key'}, cache.as_dict())
-        cache['test2'] = 'key that is too big'
+        self.assertEqual({"test": "key"}, cache.as_dict())
+        cache["test2"] = "key that is too big"
         self.assertEqual(3, cache._value_size)
-        self.assertEqual({'test': 'key'}, cache.as_dict())
+        self.assertEqual({"test": "key"}, cache.as_dict())
         # If we would add a key, only to cleanup and remove all cached entries,
         # then obviously that value should not be stored
-        cache['test3'] = 'bigkey'
+        cache["test3"] = "bigkey"
         self.assertEqual(3, cache._value_size)
-        self.assertEqual({'test': 'key'}, cache.as_dict())
+        self.assertEqual({"test": "key"}, cache.as_dict())
 
-        cache['test4'] = 'bikey'
+        cache["test4"] = "bikey"
         self.assertEqual(3, cache._value_size)
-        self.assertEqual({'test': 'key'}, cache.as_dict())
+        self.assertEqual({"test": "key"}, cache.as_dict())
 
     def test_adding_clears_cache_based_on_size(self):
-        """The cache is cleared in LRU order until small enough"""
+        """The cache is cleared in LRU order until small enough."""
         cache = lru_cache.LRUSizeCache(max_size=20)
-        cache['key1'] = 'value'  # 5 chars
-        cache['key2'] = 'value2'  # 6 chars
-        cache['key3'] = 'value23'  # 7 chars
+        cache["key1"] = "value"  # 5 chars
+        cache["key2"] = "value2"  # 6 chars
+        cache["key3"] = "value23"  # 7 chars
         self.assertEqual(5 + 6 + 7, cache._value_size)
-        cache['key2']  # reference key2 so it gets a newer reference time
-        cache['key4'] = 'value234'  # 8 chars, over limit
+        cache["key2"]  # reference key2 so it gets a newer reference time
+        cache["key4"] = "value234"  # 8 chars, over limit
         # We have to remove 2 keys to get back under limit
         self.assertEqual(6 + 8, cache._value_size)
-        self.assertEqual({'key2': 'value2', 'key4': 'value234'},
-                         cache.as_dict())
+        self.assertEqual({"key2": "value2", "key4": "value234"}, cache.as_dict())
 
     def test_adding_clears_to_after_cleanup_size(self):
         cache = lru_cache.LRUSizeCache(max_size=20, after_cleanup_size=10)
-        cache['key1'] = 'value'  # 5 chars
-        cache['key2'] = 'value2'  # 6 chars
-        cache['key3'] = 'value23'  # 7 chars
+        cache["key1"] = "value"  # 5 chars
+        cache["key2"] = "value2"  # 6 chars
+        cache["key3"] = "value23"  # 7 chars
         self.assertEqual(5 + 6 + 7, cache._value_size)
-        cache['key2']  # reference key2 so it gets a newer reference time
-        cache['key4'] = 'value234'  # 8 chars, over limit
+        cache["key2"]  # reference key2 so it gets a newer reference time
+        cache["key4"] = "value234"  # 8 chars, over limit
         # We have to remove 3 keys to get back under limit
         self.assertEqual(8, cache._value_size)
-        self.assertEqual({'key4': 'value234'}, cache.as_dict())
+        self.assertEqual({"key4": "value234"}, cache.as_dict())
 
     def test_custom_sizes(self):
         def size_of_list(lst):
             return sum(len(x) for x in lst)
-        cache = lru_cache.LRUSizeCache(max_size=20, after_cleanup_size=10,
-                                       compute_size=size_of_list)
 
-        cache['key1'] = ['val', 'ue']  # 5 chars
-        cache['key2'] = ['val', 'ue2']  # 6 chars
-        cache['key3'] = ['val', 'ue23']  # 7 chars
+        cache = lru_cache.LRUSizeCache(
+            max_size=20, after_cleanup_size=10, compute_size=size_of_list
+        )
+
+        cache["key1"] = ["val", "ue"]  # 5 chars
+        cache["key2"] = ["val", "ue2"]  # 6 chars
+        cache["key3"] = ["val", "ue23"]  # 7 chars
         self.assertEqual(5 + 6 + 7, cache._value_size)
-        cache['key2']  # reference key2 so it gets a newer reference time
-        cache['key4'] = ['value', '234']  # 8 chars, over limit
+        cache["key2"]  # reference key2 so it gets a newer reference time
+        cache["key4"] = ["value", "234"]  # 8 chars, over limit
         # We have to remove 3 keys to get back under limit
         self.assertEqual(8, cache._value_size)
-        self.assertEqual({'key4': ['value', '234']}, cache.as_dict())
+        self.assertEqual({"key4": ["value", "234"]}, cache.as_dict())
 
     def test_cleanup(self):
         cache = lru_cache.LRUSizeCache(max_size=20, after_cleanup_size=10)
 
         # Add these in order
-        cache['key1'] = 'value'  # 5 chars
-        cache['key2'] = 'value2'  # 6 chars
-        cache['key3'] = 'value23'  # 7 chars
+        cache["key1"] = "value"  # 5 chars
+        cache["key2"] = "value2"  # 6 chars
+        cache["key3"] = "value23"  # 7 chars
         self.assertEqual(5 + 6 + 7, cache._value_size)
 
         cache.cleanup()
@@ -384,40 +389,40 @@ class TestLRUSizeCache(tests.TestCase):
     def test_keys(self):
         cache = lru_cache.LRUSizeCache(max_size=10)
 
-        cache[1] = 'a'
-        cache[2] = 'b'
-        cache[3] = 'cdef'
+        cache[1] = "a"
+        cache[2] = "b"
+        cache[3] = "cdef"
         self.assertEqual([1, 2, 3], sorted(cache.keys()))
 
     def test_resize_smaller(self):
         cache = lru_cache.LRUSizeCache(max_size=10, after_cleanup_size=9)
-        cache[1] = 'abc'
-        cache[2] = 'def'
-        cache[3] = 'ghi'
-        cache[4] = 'jkl'
+        cache[1] = "abc"
+        cache[2] = "def"
+        cache[3] = "ghi"
+        cache[4] = "jkl"
         # Triggers a cleanup
         self.assertEqual([2, 3, 4], sorted(cache.keys()))
         # Resize should also cleanup again
         cache.resize(max_size=6, after_cleanup_size=4)
         self.assertEqual([4], sorted(cache.keys()))
         # Adding should use the new max size
-        cache[5] = 'mno'
+        cache[5] = "mno"
         self.assertEqual([4, 5], sorted(cache.keys()))
-        cache[6] = 'pqr'
+        cache[6] = "pqr"
         self.assertEqual([6], sorted(cache.keys()))
 
     def test_resize_larger(self):
         cache = lru_cache.LRUSizeCache(max_size=10, after_cleanup_size=9)
-        cache[1] = 'abc'
-        cache[2] = 'def'
-        cache[3] = 'ghi'
-        cache[4] = 'jkl'
+        cache[1] = "abc"
+        cache[2] = "def"
+        cache[3] = "ghi"
+        cache[4] = "jkl"
         # Triggers a cleanup
         self.assertEqual([2, 3, 4], sorted(cache.keys()))
         cache.resize(max_size=15, after_cleanup_size=12)
         self.assertEqual([2, 3, 4], sorted(cache.keys()))
-        cache[5] = 'mno'
-        cache[6] = 'pqr'
+        cache[5] = "mno"
+        cache[6] = "pqr"
         self.assertEqual([2, 3, 4, 5, 6], sorted(cache.keys()))
-        cache[7] = 'stu'
+        cache[7] = "stu"
         self.assertEqual([4, 5, 6, 7], sorted(cache.keys()))
