@@ -9,12 +9,16 @@
 import sys
 
 if sys.frozen == "windows_exe":
+
     class Blackhole:
         softspace = 0
+
         def write(self, text):
             pass
+
         def flush(self):
             pass
+
     sys.stdout = Blackhole()
     sys.stderr = Blackhole()
     del Blackhole
@@ -23,7 +27,7 @@ if sys.frozen == "windows_exe":
 # required by some plugins (see bug #743256)
 import os
 
-sys.path.append(os.path.join(os.path.dirname(sys.executable), 'site-packages'))
+sys.path.append(os.path.join(os.path.dirname(sys.executable), "site-packages"))
 del os
 del sys
 
@@ -37,7 +41,9 @@ import linecache
 
 
 def fake_getline(filename, lineno, module_globals=None):
-    return ''
+    return ""
+
+
 linecache.orig_getline = linecache.getline
 linecache.getline = fake_getline
 
